@@ -84,12 +84,37 @@ __all__ = ['Saver']
 class Saver(type):
     """
     Drop this into unittest.TestCase as a metaclass, to make failing cases fail consistently.
-   
+    
+    For example:
+    
+    >>> import random
+    >>> 
+    >>> import unittest_rand_gen_state
+    >>> 
+    >>> 
+    >>>     class TestMyAlgs(unittest.TestCase, metaclass = unittest_rand_gen_state.Saver):
+    >>>         ...
+
+    or, using an older Python version:
+
+    >>> import random
+    >>> 
+    >>> import unittest_rand_gen_state
+    >>> 
+    >>> 
+    >>> class TestMyAlgs(unittest.TestCase):
+    >>>     __metaclass__ = unittest_rand_gen_state.Saver
+    >>>     ...   
+    
+    
     The library may be extended by dropping as a metaclass, a subclass supplying three class methods:
    
-    * ``reset_state``: A method specifying the meaning of resetting the random-generation state (e.g., ``random.seed``)
-    * ``get_state``: A method specifying the query to call for getting the current random-generation state (e.g., ``random.getstate``)
-    * ``set_state``: A method specifying the function to call to restore the random-generation state using the value returned by ``get_state`` (e.g., ``random.setstate``)
+    * ``reset_state``: A method specifying the meaning of resetting the random-generation state 
+        (e.g., ``random.seed``)
+    * ``get_state``: A method specifying the query to call for getting the current random-generation state 
+        (e.g., ``random.getstate``)
+    * ``set_state``: A method specifying the function to call to restore the random-generation state 
+        using the value returned by ``get_state`` (e.g., ``random.setstate``)
     """
    
     if _has_numpy_rand:
